# Copyright (c) 2023 TheraPanacea. All rights Reserved.
# Unauthorized copying of this file, via any medium is strictly prohibited
# Proprietary and confidential
"""Tools to plot images and features returns by the sdk."""
import matplotlib.pyplot as plt
import numpy as np

from artist import iobox


def slices(
    urls: dict[str, str],
    formats: dict[str, str],
    axes=None,
    zslice: int | None = None,
    num_cols: int = 3
):
    """Plot the images from a dictionary of urls."""
    if axes is None:
        num_rows = int(np.ceil(len(urls) / num_cols))
        num_cols = int(np.ceil(len(urls) / num_rows))
        _, axes = plt.subplots(
            num_rows, num_cols, figsize=(num_cols * 7, num_rows * 4)
        )

    fmts = {k: formats for k in urls} if isinstance(formats, str) else formats
    for ax, (name, url) in zip(axes.ravel(), urls.items()):
        data = iobox.download_image(url[0], fmts.get(name, 'NIFTI')).get_fdata()
        z = data.shape[-1] // 2 if zslice is None else zslice
        ax.imshow(data[..., z])
        ax.set_title(f'{name}\n{data.shape}', fontsize=20)
    plt.tight_layout()
    return axes


def radiomics(url, num_cols: int = 5, axes=None):
    """Download and plots radiomics features."""
    data = iobox.download_image(url, 'NUMPY')
    size = data['features'].size
    if axes is None:
        num_rows = int(np.ceil(size / num_cols))
        num_cols = int(np.ceil(size / num_rows))
        _, axes = plt.subplots(
            num_rows, num_cols, figsize=(num_cols * 6, num_rows * 6)
        )

    for ax, feature, i in zip(axes.ravel(), data['features'], range(size)):
        ax.imshow(np.sum(data['data'][..., i], axis=0), cmap='inferno')
        ax.set_title(feature, fontsize=16)
    return axes
